==> keycloak-model-map-21.0.0-sources.jar: org/keycloak/models/map/userSession/MapUserSessionEntityFieldDelegate.java <==
package org.keycloak.models.map.userSession;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateEntityImplementationsProcessor")
public class MapUserSessionEntityFieldDelegate extends org.keycloak.models.map.userSession.MapUserSessionEntity.AbstractUserSessionEntity implements org.keycloak.models.map.userSession.MapUserSessionEntity, org.keycloak.models.map.common.delegate.HasEntityFieldDelegate<org.keycloak.models.map.userSession.MapUserSessionEntity> {
    private final org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.userSession.MapUserSessionEntity> entityFieldDelegate;
    public MapUserSessionEntityFieldDelegate(org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.userSession.MapUserSessionEntity> entityFieldDelegate) {
        this.entityFieldDelegate = entityFieldDelegate;
    }
    public org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.userSession.MapUserSessionEntity> getEntityFieldDelegate() {
        return this.entityFieldDelegate;
    }
    @Override public boolean isUpdated() {
        return entityFieldDelegate.isUpdated();
    }
    @Override public void clearUpdatedFlag() {
        entityFieldDelegate.clearUpdatedFlag();
    }
    @SuppressWarnings("unchecked") @Override public String getId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.userSession.MapUserSessionEntityFields.ID);
    }
    @SuppressWarnings("unchecked") @Override public void setId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.userSession.MapUserSessionEntityFields.ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public Long getExpiration() {
        return (Long) entityFieldDelegate.get(org.keycloak.models.map.userSession.MapUserSessionEntityFields.EXPIRATION);
    }
    @SuppressWarnings("unchecked") @Override public void setExpiration(Long p0) {
        entityFieldDelegate.set(org.keycloak.models.map.userSession.MapUserSessionEntityFields.EXPIRATION, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getRealmId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.userSession.MapUserSessionEntityFields.REALM_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setRealmId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.userSession.MapUserSessionEntityFields.REALM_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getUserId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.userSession.MapUserSessionEntityFields.USER_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setUserId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.userSession.MapUserSessionEntityFields.USER_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getBrokerSessionId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.userSession.MapUserSessionEntityFields.BROKER_SESSION_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setBrokerSessionId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.userSession.MapUserSessionEntityFields.BROKER_SESSION_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getBrokerUserId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.userSession.MapUserSessionEntityFields.BROKER_USER_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setBrokerUserId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.userSession.MapUserSessionEntityFields.BROKER_USER_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getLoginUsername() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.userSession.MapUserSessionEntityFields.LOGIN_USERNAME);
    }
    @SuppressWarnings("unchecked") @Override public void setLoginUsername(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.userSession.MapUserSessionEntityFields.LOGIN_USERNAME, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getIpAddress() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.userSession.MapUserSessionEntityFields.IP_ADDRESS);
    }
    @SuppressWarnings("unchecked") @Override public void setIpAddress(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.userSession.MapUserSessionEntityFields.IP_ADDRESS, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getAuthMethod() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.userSession.MapUserSessionEntityFields.AUTH_METHOD);
    }
    @SuppressWarnings("unchecked") @Override public void setAuthMethod(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.userSession.MapUserSessionEntityFields.AUTH_METHOD, p0);
    }
    @SuppressWarnings("unchecked") @Override public Boolean isRememberMe() {
        return (Boolean) entityFieldDelegate.get(org.keycloak.models.map.userSession.MapUserSessionEntityFields.REMEMBER_ME);
    }
    @SuppressWarnings("unchecked") @Override public void setRememberMe(Boolean p0) {
        entityFieldDelegate.set(org.keycloak.models.map.userSession.MapUserSessionEntityFields.REMEMBER_ME, p0);
    }
    @SuppressWarnings("unchecked") @Override public Long getTimestamp() {
        return (Long) entityFieldDelegate.get(org.keycloak.models.map.userSession.MapUserSessionEntityFields.TIMESTAMP);
    }
    @SuppressWarnings("unchecked") @Override public void setTimestamp(Long p0) {
        entityFieldDelegate.set(org.keycloak.models.map.userSession.MapUserSessionEntityFields.TIMESTAMP, p0);
    }
    @SuppressWarnings("unchecked") @Override public Long getLastSessionRefresh() {
        return (Long) entityFieldDelegate.get(org.keycloak.models.map.userSession.MapUserSessionEntityFields.LAST_SESSION_REFRESH);
    }
    @SuppressWarnings("unchecked") @Override public void setLastSessionRefresh(Long p0) {
        entityFieldDelegate.set(org.keycloak.models.map.userSession.MapUserSessionEntityFields.LAST_SESSION_REFRESH, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.Map<String,String> getNotes() {
        return (java.util.Map<String,String>) entityFieldDelegate.get(org.keycloak.models.map.userSession.MapUserSessionEntityFields.NOTES);
    }
    @SuppressWarnings("unchecked") @Override public String getNote(String p0) {
        return (String) entityFieldDelegate.mapGet(org.keycloak.models.map.userSession.MapUserSessionEntityFields.NOTES, p0);
    }
    @SuppressWarnings("unchecked") @Override public void setNotes(java.util.Map<String,String> p0) {
        entityFieldDelegate.set(org.keycloak.models.map.userSession.MapUserSessionEntityFields.NOTES, p0);
    }
    @SuppressWarnings("unchecked") @Override public Boolean removeNote(String p0) {
        return (Boolean) entityFieldDelegate.mapRemove(org.keycloak.models.map.userSession.MapUserSessionEntityFields.NOTES, p0);
    }
    @SuppressWarnings("unchecked") @Override public void setNote(String p0, String p1) {
        entityFieldDelegate.mapPut(org.keycloak.models.map.userSession.MapUserSessionEntityFields.NOTES, p0, p1);
    }
    @SuppressWarnings("unchecked") @Override public org.keycloak.models.UserSessionModel.State getState() {
        return (org.keycloak.models.UserSessionModel.State) entityFieldDelegate.get(org.keycloak.models.map.userSession.MapUserSessionEntityFields.STATE);
    }
    @SuppressWarnings("unchecked") @Override public void setState(org.keycloak.models.UserSessionModel.State p0) {
        entityFieldDelegate.set(org.keycloak.models.map.userSession.MapUserSessionEntityFields.STATE, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.Set<org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntity> getAuthenticatedClientSessions() {
        return (java.util.Set<org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntity>) entityFieldDelegate.get(org.keycloak.models.map.userSession.MapUserSessionEntityFields.AUTHENTICATED_CLIENT_SESSIONS);
    }
    @SuppressWarnings("unchecked") @Override public java.util.Optional<org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntity> getAuthenticatedClientSession(String p0) {
        return (java.util.Optional<org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntity>) entityFieldDelegate.mapGet(org.keycloak.models.map.userSession.MapUserSessionEntityFields.AUTHENTICATED_CLIENT_SESSIONS, p0);
    }
    @SuppressWarnings("unchecked") @Override public void addAuthenticatedClientSession(org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntity p0) {
        entityFieldDelegate.collectionAdd(org.keycloak.models.map.userSession.MapUserSessionEntityFields.AUTHENTICATED_CLIENT_SESSIONS, p0);
    }
    @SuppressWarnings("unchecked") @Override public Boolean removeAuthenticatedClientSession(String p0) {
        return (Boolean) entityFieldDelegate.mapRemove(org.keycloak.models.map.userSession.MapUserSessionEntityFields.AUTHENTICATED_CLIENT_SESSIONS, p0);
    }
    @SuppressWarnings("unchecked") @Override public Boolean isOffline() {
        return (Boolean) entityFieldDelegate.get(org.keycloak.models.map.userSession.MapUserSessionEntityFields.OFFLINE);
    }
    @SuppressWarnings("unchecked") @Override public void setOffline(Boolean p0) {
        entityFieldDelegate.set(org.keycloak.models.map.userSession.MapUserSessionEntityFields.OFFLINE, p0);
    }
    @SuppressWarnings("unchecked") @Override public org.keycloak.models.UserSessionModel.SessionPersistenceState getPersistenceState() {
        return (org.keycloak.models.UserSessionModel.SessionPersistenceState) entityFieldDelegate.get(org.keycloak.models.map.userSession.MapUserSessionEntityFields.PERSISTENCE_STATE);
    }
    @SuppressWarnings("unchecked") @Override public void setPersistenceState(org.keycloak.models.UserSessionModel.SessionPersistenceState p0) {
        entityFieldDelegate.set(org.keycloak.models.map.userSession.MapUserSessionEntityFields.PERSISTENCE_STATE, p0);
    }
}

==> keycloak-model-map-22.0.0-sources.jar: org/keycloak/models/map/userSession/MapUserSessionEntityFieldDelegate.java <==
package org.keycloak.models.map.userSession;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateEntityImplementationsProcessor")
public class MapUserSessionEntityFieldDelegate extends org.keycloak.models.map.userSession.MapUserSessionEntity.AbstractUserSessionEntity implements org.keycloak.models.map.userSession.MapUserSessionEntity, org.keycloak.models.map.common.delegate.HasEntityFieldDelegate<org.keycloak.models.map.userSession.MapUserSessionEntity> {
    private final org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.userSession.MapUserSessionEntity> entityFieldDelegate;
    public MapUserSessionEntityFieldDelegate(org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.userSession.MapUserSessionEntity> entityFieldDelegate) {
        this.entityFieldDelegate = entityFieldDelegate;
    }
    public org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.userSession.MapUserSessionEntity> getEntityFieldDelegate() {
        return this.entityFieldDelegate;
    }
    @Override public boolean isUpdated() {
        return entityFieldDelegate.isUpdated();
    }
    @Override public void markUpdatedFlag() {
        entityFieldDelegate.markUpdatedFlag();
    }
    @Override public void clearUpdatedFlag() {
        entityFieldDelegate.clearUpdatedFlag();
    }
    @Override public String toString() {
        return "%" + String.valueOf(entityFieldDelegate);
    }
    @SuppressWarnings("unchecked") @Override public String getId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.userSession.MapUserSessionEntityFields.ID);
    }
    @SuppressWarnings("unchecked") @Override public void setId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.userSession.MapUserSessionEntityFields.ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public Long getExpiration() {
        return (Long) entityFieldDelegate.get(org.keycloak.models.map.userSession.MapUserSessionEntityFields.EXPIRATION);
    }
    @SuppressWarnings("unchecked") @Override public void setExpiration(Long p0) {
        entityFieldDelegate.set(org.keycloak.models.map.userSession.MapUserSessionEntityFields.EXPIRATION, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getRealmId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.userSession.MapUserSessionEntityFields.REALM_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setRealmId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.userSession.MapUserSessionEntityFields.REALM_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getUserId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.userSession.MapUserSessionEntityFields.USER_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setUserId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.userSession.MapUserSessionEntityFields.USER_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getBrokerSessionId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.userSession.MapUserSessionEntityFields.BROKER_SESSION_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setBrokerSessionId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.userSession.MapUserSessionEntityFields.BROKER_SESSION_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getBrokerUserId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.userSession.MapUserSessionEntityFields.BROKER_USER_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setBrokerUserId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.userSession.MapUserSessionEntityFields.BROKER_USER_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getLoginUsername() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.userSession.MapUserSessionEntityFields.LOGIN_USERNAME);
    }
    @SuppressWarnings("unchecked") @Override public void setLoginUsername(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.userSession.MapUserSessionEntityFields.LOGIN_USERNAME, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getIpAddress() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.userSession.MapUserSessionEntityFields.IP_ADDRESS);
    }
    @SuppressWarnings("unchecked") @Override public void setIpAddress(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.userSession.MapUserSessionEntityFields.IP_ADDRESS, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getAuthMethod() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.userSession.MapUserSessionEntityFields.AUTH_METHOD);
    }
    @SuppressWarnings("unchecked") @Override public void setAuthMethod(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.userSession.MapUserSessionEntityFields.AUTH_METHOD, p0);
    }
    @SuppressWarnings("unchecked") @Override public Boolean isRememberMe() {
        return (Boolean) entityFieldDelegate.get(org.keycloak.models.map.userSession.MapUserSessionEntityFields.REMEMBER_ME);
    }
    @SuppressWarnings("unchecked") @Override public void setRememberMe(Boolean p0) {
        entityFieldDelegate.set(org.keycloak.models.map.userSession.MapUserSessionEntityFields.REMEMBER_ME, p0);
    }
    @SuppressWarnings("unchecked") @Override public Long getTimestamp() {
        return (Long) entityFieldDelegate.get(org.keycloak.models.map.userSession.MapUserSessionEntityFields.TIMESTAMP);
    }
    @SuppressWarnings("unchecked") @Override public void setTimestamp(Long p0) {
        entityFieldDelegate.set(org.keycloak.models.map.userSession.MapUserSessionEntityFields.TIMESTAMP, p0);
    }
    @SuppressWarnings("unchecked") @Override public Long getLastSessionRefresh() {
        return (Long) entityFieldDelegate.get(org.keycloak.models.map.userSession.MapUserSessionEntityFields.LAST_SESSION_REFRESH);
    }
    @SuppressWarnings("unchecked") @Override public void setLastSessionRefresh(Long p0) {
        entityFieldDelegate.set(org.keycloak.models.map.userSession.MapUserSessionEntityFields.LAST_SESSION_REFRESH, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.Map<String,String> getNotes() {
        return (java.util.Map<String,String>) entityFieldDelegate.get(org.keycloak.models.map.userSession.MapUserSessionEntityFields.NOTES);
    }
    @SuppressWarnings("unchecked") @Override public String getNote(String p0) {
        return (String) entityFieldDelegate.mapGet(org.keycloak.models.map.userSession.MapUserSessionEntityFields.NOTES, p0);
    }
    @SuppressWarnings("unchecked") @Override public void setNotes(java.util.Map<String,String> p0) {
        entityFieldDelegate.set(org.keycloak.models.map.userSession.MapUserSessionEntityFields.NOTES, p0);
    }
    @SuppressWarnings("unchecked") @Override public Boolean removeNote(String p0) {
        return (Boolean) entityFieldDelegate.mapRemove(org.keycloak.models.map.userSession.MapUserSessionEntityFields.NOTES, p0);
    }
    @SuppressWarnings("unchecked") @Override public void setNote(String p0, String p1) {
        entityFieldDelegate.mapPut(org.keycloak.models.map.userSession.MapUserSessionEntityFields.NOTES, p0, p1);
    }
    @SuppressWarnings("unchecked") @Override public org.keycloak.models.UserSessionModel.State getState() {
        return (org.keycloak.models.UserSessionModel.State) entityFieldDelegate.get(org.keycloak.models.map.userSession.MapUserSessionEntityFields.STATE);
    }
    @SuppressWarnings("unchecked") @Override public void setState(org.keycloak.models.UserSessionModel.State p0) {
        entityFieldDelegate.set(org.keycloak.models.map.userSession.MapUserSessionEntityFields.STATE, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.Set<org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntity> getAuthenticatedClientSessions() {
        return (java.util.Set<org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntity>) entityFieldDelegate.get(org.keycloak.models.map.userSession.MapUserSessionEntityFields.AUTHENTICATED_CLIENT_SESSIONS);
    }
    @SuppressWarnings("unchecked") @Override public java.util.Optional<org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntity> getAuthenticatedClientSession(String p0) {
        return (java.util.Optional<org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntity>) entityFieldDelegate.mapGet(org.keycloak.models.map.userSession.MapUserSessionEntityFields.AUTHENTICATED_CLIENT_SESSIONS, p0);
    }
    @SuppressWarnings("unchecked") @Override public void addAuthenticatedClientSession(org.keycloak.models.map.userSession.MapAuthenticatedClientSessionEntity p0) {
        entityFieldDelegate.collectionAdd(org.keycloak.models.map.userSession.MapUserSessionEntityFields.AUTHENTICATED_CLIENT_SESSIONS, p0);
    }
    @SuppressWarnings("unchecked") @Override public Boolean removeAuthenticatedClientSession(String p0) {
        return (Boolean) entityFieldDelegate.mapRemove(org.keycloak.models.map.userSession.MapUserSessionEntityFields.AUTHENTICATED_CLIENT_SESSIONS, p0);
    }
    @SuppressWarnings("unchecked") @Override public Boolean isOffline() {
        return (Boolean) entityFieldDelegate.get(org.keycloak.models.map.userSession.MapUserSessionEntityFields.OFFLINE);
    }
    @SuppressWarnings("unchecked") @Override public void setOffline(Boolean p0) {
        entityFieldDelegate.set(org.keycloak.models.map.userSession.MapUserSessionEntityFields.OFFLINE, p0);
    }
    @SuppressWarnings("unchecked") @Override public org.keycloak.models.UserSessionModel.SessionPersistenceState getPersistenceState() {
        return (org.keycloak.models.UserSessionModel.SessionPersistenceState) entityFieldDelegate.get(org.keycloak.models.map.userSession.MapUserSessionEntityFields.PERSISTENCE_STATE);
    }
    @SuppressWarnings("unchecked") @Override public void setPersistenceState(org.keycloak.models.UserSessionModel.SessionPersistenceState p0) {
        entityFieldDelegate.set(org.keycloak.models.map.userSession.MapUserSessionEntityFields.PERSISTENCE_STATE, p0);
    }
}
